# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [0.1.0](https://github.com/csiro-hydroinformatics/efts-io/releases/tag/0.1.0) - 2025-07-21

<small>[Compare with first commit](https://github.com/csiro-hydroinformatics/efts-io/compare/4481803cae41eb7f0315c97a864f1d0c7751d4d8...0.1.0)</small>

### Features

- initial implementation of the `save_to_stf2` method to save data in STF2 format
- include sample data in the package ([9c3fcbd](https://github.com/csiro-hydroinformatics/efts-io/commit/9c3fcbdac3f336634700463f70c4985de2f9a940) by J-M).

### Bug Fixes

- likely bug in writing the long name of a simulated variable ([4bd0106](https://github.com/csiro-hydroinformatics/efts-io/commit/4bd010600fc83dc1287e0c457e941d33909d8d71) by J-M).

## [0.0.1](https://github.com/csiro-hydroinformatics/efts-io/releases/tag/0.0.1) - 2024-08-29

<small>[Compare with first commit](https://github.com/csiro-hydroinformatics/efts-io/compare/4481803cae41eb7f0315c97a864f1d0c7751d4d8...0.0.1)</small>
